@@ -1,33 +1,33 @@
 import re
-from abc import ABC
-from inspect import isclass
+from inspect import isawaitable, isclass
+from itertools import chain
 from typing import Any, Dict, ItemsView, List, Optional, Tuple, Union, cast
 from uuid import UUID
 
 from pydantic import validate_arguments
 from pydantic.typing import AnyCallable
+from starlette.requests import HTTPConnection
 from starlette.routing import get_name
 from starlette.types import Receive, Scope, Send
 from typing_extensions import Type
 
+from starlite.connection import Request, WebSocket
 from starlite.controller import Controller
 from starlite.enums import HttpMethod, ScopeType
-from starlite.exceptions import (
-    ImproperlyConfiguredException,
-    MethodNotAllowedException,
-    ValidationException,
-)
+from starlite.exceptions import ImproperlyConfiguredException, MethodNotAllowedException
 from starlite.handlers import (
     ASGIRouteHandler,
     BaseRouteHandler,
     HTTPRouteHandler,
     WebsocketRouteHandler,
 )
+from starlite.kwargs import KwargsModel
 from starlite.provide import Provide
-from starlite.request import Request, WebSocket
 from starlite.response import Response
+from starlite.signature import get_signature_model
 from starlite.types import (
     AfterRequestHandler,
+    AsyncAnyCallable,
     BeforeRequestHandler,
     ControllerRouterHandler,
     Guard,
@@ -38,10 +38,8 @@ from starlite.utils import find_index, join_paths, normalize_path, unique
 
 param_match_regex = re.compile(r"{(.*?)}")
 
-param_type_map = {"str": str, "int": int, "float": float, "uuid": UUID}
 
-
-class BaseRoute(ABC):
+class BaseRoute:
     __slots__ = (
         "app",
         "handler_names",
@@ -65,9 +63,9 @@ class BaseRoute(ABC):
         self.path, self.path_format, self.path_parameters = self.parse_path(path)
         self.handler_names = handler_names
         self.scope_type = scope_type
-        self.methods = methods or []
+        self.methods = set(methods or [])
         if "GET" in self.methods:
-            self.methods.append("HEAD")
+            self.methods.add("HEAD")
 
     @staticmethod
     def parse_path(path: str) -> Tuple[str, str, List[Dict[str, Any]]]:
@@ -78,33 +76,34 @@ class BaseRoute(ABC):
         path_format = path
         path_parameters = []
 
+        param_type_map = {"str": str, "int": int, "float": float, "uuid": UUID}
+
         for param in param_match_regex.findall(path):
             if ":" not in param:
-                raise ImproperlyConfiguredException("path parameter must declare a type: '{parameter_name:type}'")
+                raise ImproperlyConfiguredException(
+                    "Path parameters should be declared with a type using the following pattern: '{parameter_name:type}', e.g. '/my-path/{my_param:int}'"
+                )
             param_name, param_type = (p.strip() for p in param.split(":"))
             path_format = path_format.replace(param, param_name)
             path_parameters.append({"name": param_name, "type": param_type_map[param_type], "full": param})
         return path, path_format, path_parameters
 
-    def parse_path_params(self, raw_params: List[str]) -> Dict[str, Any]:
+    def create_handler_kwargs_model(self, route_handler: BaseRouteHandler) -> KwargsModel:
         """
-        Parses raw path parameters by mapping them into a dictionary
+        Method to create a KwargsModel for a given route handler
         """
-        parsed_params: Dict[str, Any] = {}
-        for index, param_definition in enumerate(self.path_parameters):
-            raw_param = raw_params[index]
-            param_name = cast(str, param_definition["name"])
-            try:
-                param_type = cast(Type, param_definition["type"])
-                parsed_params[param_name] = param_type(raw_param)
-            except (ValueError, TypeError) as e:  # pragma: no cover
-                raise ValidationException(f"unable to parse path parameter {str(raw_param)}") from e
-        return parsed_params
+        dependencies = route_handler.resolve_dependencies()
+        signature_model = get_signature_model(route_handler)
+        path_parameters = {p["name"] for p in self.path_parameters}
+        return KwargsModel.create_for_signature_model(
+            signature_model=signature_model, dependencies=dependencies, path_parameters=path_parameters
+        )
 
 
 class HTTPRoute(BaseRoute):
     __slots__ = (
         "route_handler_map",
+        "route_handlers"
         # the rest of __slots__ are defined in BaseRoute and should not be duplicated
         # see: https://stackoverflow.com/questions/472000/usage-of-slots
     )
@@ -114,32 +113,17 @@ class HTTPRoute(BaseRoute):
         self,
         *,
         path: str,
-        route_handlers: Union[HTTPRouteHandler, List[HTTPRouteHandler]],
+        route_handlers: List[HTTPRouteHandler],
     ):
-        route_handlers = route_handlers if isinstance(route_handlers, list) else [route_handlers]
-        self.route_handler_map = self.parse_route_handlers(route_handlers=route_handlers, path=path)
+        self.route_handlers = route_handlers
+        self.route_handler_map: Dict[Method, Tuple[HTTPRouteHandler, KwargsModel]] = {}
         super().__init__(
-            methods=[cast(Method, method.upper()) for method in self.route_handler_map],
+            methods=list(chain.from_iterable([route_handler.http_methods for route_handler in route_handlers])),
             path=path,
             scope_type=ScopeType.HTTP,
             handler_names=[get_name(cast(AnyCallable, route_handler.fn)) for route_handler in route_handlers],
         )
 
-    @staticmethod
-    def parse_route_handlers(route_handlers: List[HTTPRouteHandler], path: str) -> Dict[HttpMethod, HTTPRouteHandler]:
-        """
-        Parses the passed in route_handlers and returns a mapping of http-methods and route handlers
-        """
-        mapped_route_handlers: Dict[HttpMethod, HTTPRouteHandler] = {}
-        for route_handler in route_handlers:
-            for http_method in route_handler.http_methods:
-                if mapped_route_handlers.get(http_method):
-                    raise ImproperlyConfiguredException(
-                        f"handler already registered for path {path!r} and http method {http_method}"
-                    )
-                mapped_route_handlers[http_method] = route_handler
-        return mapped_route_handlers
-
     async def handle(self, scope: Scope, receive: Receive, send: Send) -> None:
         """
         ASGI app that creates a Request from the passed in args, and then awaits a Response
@@ -147,15 +131,61 @@ class HTTPRoute(BaseRoute):
         if scope["method"] not in self.methods:
             raise MethodNotAllowedException()
         request: Request[Any, Any] = Request(scope=scope, receive=receive, send=send)
-        request_method = HttpMethod.from_str(request.method)
-        handler = self.route_handler_map[request_method]
-        response = await handler.handle_request(request=request)
+
+        route_handler, parameter_model = self.route_handler_map[request.method]
+        if route_handler.resolve_guards():
+            await route_handler.authorize_connection(connection=request)
+        response_data = None
+        before_request_handler = route_handler.resolve_before_request()
+        # run the before_request hook handler
+        if before_request_handler:
+            response_data = before_request_handler(request)
+            if isawaitable(response_data):
+                response_data = await response_data
+        if not response_data:
+            signature_model = get_signature_model(route_handler)
+            if signature_model.has_kwargs:
+                kwargs = parameter_model.to_kwargs(connection=request)
+                request_data = kwargs.get("data")
+                if request_data:
+                    kwargs["data"] = await request_data
+                for dependency in parameter_model.expected_dependencies:
+                    kwargs[dependency.key] = await parameter_model.resolve_dependency(
+                        dependency=dependency, connection=request, **kwargs
+                    )
+                parsed_kwargs = signature_model.parse_values_from_connection_kwargs(connection=request, **kwargs)
+            else:
+                parsed_kwargs = {}
+            fn = cast(AnyCallable, route_handler.fn)
+            if isinstance(route_handler.owner, Controller):
+                response_data = fn(route_handler.owner, **parsed_kwargs)
+            else:
+                response_data = fn(**parsed_kwargs)
+        response = await route_handler.to_response(
+            app=scope["app"],
+            data=response_data,
+            plugins=request.app.plugins,
+        )
         await response(scope, receive, send)
 
+    def create_handler_map(self) -> None:
+        """
+        Parses the passed in route_handlers and returns a mapping of http-methods and route handlers
+        """
+        for route_handler in self.route_handlers:
+            kwargs_model = self.create_handler_kwargs_model(route_handler=route_handler)
+            for http_method in route_handler.http_methods:
+                if self.route_handler_map.get(http_method):
+                    raise ImproperlyConfiguredException(
+                        f"Handler already registered for path {self.path!r} and http method {http_method}"
+                    )
+                self.route_handler_map[http_method] = (route_handler, kwargs_model)
+
 
 class WebSocketRoute(BaseRoute):
     __slots__ = (
         "route_handler",
+        "handler_parameter_model"
         # the rest of __slots__ are defined in BaseRoute and should not be duplicated
         # see: https://stackoverflow.com/questions/472000/usage-of-slots
     )
@@ -168,6 +198,7 @@ class WebSocketRoute(BaseRoute):
         route_handler: WebsocketRouteHandler,
     ):
         self.route_handler = route_handler
+        self.handler_parameter_model: Optional[KwargsModel] = None
         super().__init__(
             path=path,
             scope_type=ScopeType.WEBSOCKET,
@@ -178,8 +209,24 @@ class WebSocketRoute(BaseRoute):
         """
         ASGI app that creates a WebSocket from the passed in args, and then awaits the handler function
         """
+        assert self.handler_parameter_model, "handler parameter model not defined"
+        route_handler = self.route_handler
         web_socket: WebSocket[Any, Any] = WebSocket(scope=scope, receive=receive, send=send)
-        await self.route_handler.handle_websocket(web_socket=web_socket)
+        if route_handler.resolve_guards():
+            await route_handler.authorize_connection(connection=web_socket)
+        signature_model = get_signature_model(route_handler)
+        handler_parameter_model = self.handler_parameter_model
+        kwargs = handler_parameter_model.to_kwargs(connection=web_socket)
+        for dependency in handler_parameter_model.expected_dependencies:
+            kwargs[dependency.key] = await self.handler_parameter_model.resolve_dependency(
+                dependency=dependency, connection=web_socket, **kwargs
+            )
+        parsed_kwargs = signature_model.parse_values_from_connection_kwargs(connection=web_socket, **kwargs)
+        fn = cast(AsyncAnyCallable, self.route_handler.fn)
+        if isinstance(route_handler.owner, Controller):
+            await fn(route_handler.owner, **parsed_kwargs)
+        else:
+            await fn(**parsed_kwargs)
 
 
 class ASGIRoute(BaseRoute):
@@ -205,9 +252,17 @@ class ASGIRoute(BaseRoute):
 
     async def handle(self, scope: Scope, receive: Receive, send: Send) -> None:
         """
-        ASGI app that creates a WebSocket from the passed in args, and then awaits the handler function
+        ASGI app that authorizes the connection and then awaits the handler function
         """
-        await self.route_handler.handle_asgi(scope=scope, receive=receive, send=send)
+
+        if self.route_handler.resolve_guards():
+            connection = HTTPConnection(scope=scope, receive=receive)
+            await self.route_handler.authorize_connection(connection=connection)
+        fn = cast(AnyCallable, self.route_handler.fn)
+        if isinstance(self.route_handler.owner, Controller):
+            await fn(self.route_handler.owner, scope=scope, receive=receive, send=send)
+        else:
+            await fn(scope=scope, receive=receive, send=send)
 
 
 class Router:
@@ -259,8 +314,9 @@ class Router:
             if isinstance(route, HTTPRoute):
                 if not isinstance(route_map.get(route.path), dict):
                     route_map[route.path] = {}
-                for method, handler in route.route_handler_map.items():
-                    route_map[route.path][method] = handler  # type: ignore
+                for route_handler in route.route_handlers:
+                    for method in route_handler.http_methods:
+                        route_map[route.path][method] = route_handler  # type: ignore
             else:
                 route_map[route.path] = cast(WebSocketRoute, route).route_handler
         return route_map
@@ -317,9 +373,7 @@ class Router:
         value.owner = self
         return cast(Union[Controller, BaseRouteHandler, "Router"], value)
 
-    def register(
-        self, value: ControllerRouterHandler
-    ) -> List[Union[HTTPRouteHandler, WebsocketRouteHandler, ASGIRouteHandler]]:
+    def register(self, value: ControllerRouterHandler) -> List[BaseRoute]:
         """
         Register a Controller, Route instance or RouteHandler on the router
 
@@ -327,29 +381,31 @@ class Router:
         by any of the routing decorators (e.g. route, get, post...) exported from 'starlite.routing'
         """
         validated_value = self.validate_registration_value(value)
-        handlers: List[Union[HTTPRouteHandler, WebsocketRouteHandler, ASGIRouteHandler]] = []
+        routes: List[BaseRoute] = []
         for route_path, handler_or_method_map in self.map_route_handlers(value=validated_value):
             path = join_paths([self.path, route_path])
             if isinstance(handler_or_method_map, WebsocketRouteHandler):
-                handlers.append(handler_or_method_map)
-                self.routes.append(WebSocketRoute(path=path, route_handler=handler_or_method_map))
+                route: BaseRoute = WebSocketRoute(path=path, route_handler=handler_or_method_map)
+                self.routes.append(route)
             elif isinstance(handler_or_method_map, ASGIRouteHandler):
-                handlers.append(handler_or_method_map)
-                self.routes.append(ASGIRoute(path=path, route_handler=handler_or_method_map))
+                route = ASGIRoute(path=path, route_handler=handler_or_method_map)
+                self.routes.append(route)
             else:
-                route_handlers = list(cast(Dict[HttpMethod, HTTPRouteHandler], handler_or_method_map).values())
-                handlers.extend(route_handlers)
-                if self.route_handler_method_map.get(path):
+                existing_handlers: List[HTTPRouteHandler] = list(self.route_handler_method_map.get(path, {}).values())  # type: ignore
+                route_handlers = unique(list(cast(Dict[HttpMethod, HTTPRouteHandler], handler_or_method_map).values()))
+                if existing_handlers:
+                    route_handlers.extend(unique(existing_handlers))
                     existing_route_index = find_index(
                         self.routes, lambda x: x.path == path  # pylint: disable=cell-var-from-loop
                     )
                     assert existing_route_index != -1, "unable to find_index existing route index"
-                    if isinstance(self.route_handler_method_map[path], dict):
-                        route_handlers.extend(list(cast(dict, self.route_handler_method_map[path]).values()))
-                    self.routes[existing_route_index] = HTTPRoute(
+                    route = HTTPRoute(
                         path=path,
-                        route_handlers=unique(route_handlers),
+                        route_handlers=route_handlers,
                     )
+                    self.routes[existing_route_index] = route
                 else:
-                    self.routes.append(HTTPRoute(path=path, route_handlers=unique(route_handlers)))
-        return unique(handlers)
+                    route = HTTPRoute(path=path, route_handlers=route_handlers)
+                    self.routes.append(route)
+            routes.append(route)
+        return routes
