@@ -31,10 +31,10 @@ except ImportError:  # pragma: no cover
     from typing import _GenericAlias as GenericAlias  # type: ignore
 
 if TYPE_CHECKING:  # pragma: no cover
+    from starlite.connection import Request
     from starlite.controller import Controller
     from starlite.datastructures import State
     from starlite.handlers import BaseRouteHandler
-    from starlite.request import Request
     from starlite.routing import Router
 else:
     Request = Any
@@ -57,6 +57,15 @@ Guard = Union[
     Callable[[HTTPConnection, BaseRouteHandler], Awaitable[None]], Callable[[HTTPConnection, BaseRouteHandler], None]
 ]
 Method = Union[Literal["GET"], Literal["POST"], Literal["DELETE"], Literal["PATCH"], Literal["PUT"], Literal["HEAD"]]
+ReservedKwargs = Union[
+    Literal["request"],
+    Literal["socket"],
+    Literal["headers"],
+    Literal["query"],
+    Literal["cookies"],
+    Literal["state"],
+    Literal["data"],
+]
 ControllerRouterHandler = Union[Type[Controller], BaseRouteHandler, Router, AnyCallable]
 
 # connection-lifecycle hook handlers
@@ -66,6 +75,8 @@ AfterRequestHandler = Union[
     Callable[[Union[StarletteResponse, Response]], Awaitable[Union[StarletteResponse, Response]]],
 ]
 
+AsyncAnyCallable = Callable[..., Awaitable[Any]]
+
 
 @runtime_checkable
 class MiddlewareProtocol(Protocol):
